==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/nb.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "Unknown user" : "Ukjent bruker",
    "New comment …" : "Ny kommentar",
    "Delete comment" : "Slett kommentar",
    "Post" : "Send",
    "Cancel" : "Avbryt",
    "Edit comment" : "Rediger kommentar",
    "[Deleted user]" : "[Slettet bruker]",
    "No comments yet, start the conversation!" : "Ingen kommentarer enda, start diskusjonen!",
    "More comments …" : "Flere kommentarer..",
    "Save" : "Lagre",
    "Allowed characters {count} of {max}" : "Antall tegn tillatt {count} av {max}",
    "Error occurred while retrieving comment with id {id}" : "En feil oppstod under henting av kommentar med id {id}",
    "Error occurred while updating comment with id {id}" : "En feil oppstod under oppdatering av kommentar med id {id}",
    "Error occurred while posting comment" : "En feil oppstod under posting av kommentar",
    "_%n unread comment_::_%n unread comments_" : ["%n ulest kommentar","%n uleste kommentarer"],
    "Comment" : "Kommentar",
    "You commented" : "Du kommenterte",
    "%1$s commented" : "%1$s kommentert",
    "{author} commented" : "{author} kommenterte",
    "You commented on %1$s" : "Du kommenterte på %1$s",
    "You commented on {file}" : "Du kommenterte på {file}",
    "%1$s commented on %2$s" : "%1$s kommenterte %2$s",
    "{author} commented on {file}" : "{author} kommenterte på {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "A (now) deleted user mentioned you in a comment on “%s”" : "En (now) slettet bruker nevnte deg i en kommentar til “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "A (now) slettet bruker nevnte deg i en kommentar til “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s nevnte deg i en kommentar på “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} nevnte deg i en kommentar på “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/nb.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "Unknown user" : "Ukjent bruker",
    "New comment …" : "Ny kommentar",
    "Delete comment" : "Slett kommentar",
    "Post" : "Send",
    "Cancel" : "Avbryt",
    "Edit comment" : "Rediger kommentar",
    "[Deleted user]" : "[Slettet bruker]",
    "No comments yet, start the conversation!" : "Ingen kommentarer enda, start diskusjonen!",
    "More comments …" : "Flere kommentarer..",
    "Save" : "Lagre",
    "Allowed characters {count} of {max}" : "Antall tegn tillatt {count} av {max}",
    "Error occurred while retrieving comment with id {id}" : "En feil oppstod under henting av kommentar med id {id}",
    "Error occurred while updating comment with id {id}" : "En feil oppstod under oppdatering av kommentar med id {id}",
    "Error occurred while posting comment" : "En feil oppstod under posting av kommentar",
    "_%n unread comment_::_%n unread comments_" : ["%n ulest kommentar","%n uleste kommentarer"],
    "Comment" : "Kommentar",
    "You commented" : "Du kommenterte",
    "%1$s commented" : "%1$s kommentert",
    "{author} commented" : "{author} kommenterte",
    "You commented on %1$s" : "Du kommenterte på %1$s",
    "You commented on {file}" : "Du kommenterte på {file}",
    "%1$s commented on %2$s" : "%1$s kommenterte %2$s",
    "{author} commented on {file}" : "{author} kommenterte på {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Du ble nevnte på \"%s\", i en kommentar av en bruker som siden har blitt slettet",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s nevnte deg i en kommentar på “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} nevnte deg i en kommentar på “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "En (now) slettet bruker nevnte deg i en kommentar til “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "A (now) slettet bruker nevnte deg i en kommentar til “{file}”"
},
"nplurals=2; plural=(n != 1);");
